<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>GnomeHotkeyFactory</name>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="29"/>
        <source>Gnome Hotkey Plugin</source>
        <translation>Wtyczka Skróty klawiszowe Gnome</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="50"/>
        <source>About Gnome Hotkey Plugin</source>
        <translation>O wtyczce Skróty klawiszowe Gnome</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="51"/>
        <source>Qmmp Gnome Hotkey Plugin</source>
        <translation>Wtyczka Skróty klawiszowe Gnome dla Qmmp</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support of the GNOME/Cinnamon hotkeys</source>
        <translation>Ta wtyczka dodaje wsparcie skrótów klawiszowych dla GNOME/Cinnamon</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
